%global with_python3 0%{?fedora}

%global __provides_filter_from ^%{python_sitearch}/.*\\.so$
%global __provides_filter_from ^%{python3_sitearch}/.*\\.so$

%global module blosc

# Use the same directory of the main package for subpackage licence and docs
%global _docdir_fmt %{name}

Summary:        Python wrapper for the blosc high performance compressor
Name:           python-%{module}
Version:        1.2.7
Release:        4%{?dist}
License:        MIT
URL:            https://github.com/FrancescAlted/python-blosc
Source0:        https://pypi.python.org/packages/source/b/%{module}/%{module}-%{version}.tar.gz
Patch0:         0001-Allow-verbosity-to-be-specified-when-running-test-su.patch
Patch1:         0002-Propagate-the-result-of-tests.patch

BuildRequires:  blosc-devel
BuildRequires:  python2-devel
BuildRequires:  numpy
Recommends:     numpy

%description
Python wrapper for the Blosc high performance compressor.

%if 0%{?with_python3}
%package -n python3-%{module}
Summary:        Python wrapper for the blosc high performance compressor
BuildRequires:  python3-devel
BuildRequires:  python3-numpy
Recommends:     python3-numpy

%description -n python3-%{module}
Python wrapper for the Blosc high performance compressor.
%endif

%prep
%autosetup -n %{module}-%{version} -p1

# Don't enable SSE2 optimizations
sed -i "s|CFLAGS\.append(\"-msse2\")|pass|" setup.py

%build
export BLOSC_DIR=%{_libdir}/blosc CFLAGS="%{optflags}"
%{__python2} setup.py build
%if 0%{?with_python3}
%{__python3} setup.py build
%endif

%install
%{__python2} setup.py install --prefix=%{_prefix} -O1 --skip-build --root=%{buildroot}
%if 0%{?with_python3}
%{__python3} setup.py install --prefix=%{_prefix} -O1 --skip-build --root=%{buildroot}
%endif

%files
%{python2_sitearch}/blosc/
%{python2_sitearch}/blosc-%{version}*-py*.egg-info
%license LICENSES/PYTHON-BLOSC.txt
%doc README.rst RELEASE_NOTES.rst

%if 0%{?with_python3}
%files -n python3-%{module}
%{python3_sitearch}/blosc/
%{python3_sitearch}/blosc-%{version}*-py*.egg-info
%license LICENSES/PYTHON-BLOSC.txt
%doc README.rst RELEASE_NOTES.rst
%endif

%check
cd / # avoid interference with build dir
PYTHONPATH=%{buildroot}%{python2_sitearch} python -c 'import sys, blosc; sys.exit(blosc.test())'
%if 0%{?with_python3}
PYTHONPATH=%{buildroot}%{python3_sitearch} python3 -c 'import sys, blosc; sys.exit(blosc.test())'
%endif

%changelog
* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.7-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri May 29 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.7-3
- Run test suite

* Thu May 28 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.7-2
- Build python 3 subpackage
- Install license and readme files

* Thu May  7 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.7-1
- Update to 1.2.7 (#1212231)

* Mon Apr 20 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.5-1
- Update to 1.2.5 (#1212231)

* Tue Jan 06 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.4-1
- Update to 1.2.4

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Mar 26 2014 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.3-2
- Rebuild for blosc

* Sat Mar 22 2014 Thibault North <tnorth@fedoraproject.org> - 1.2.3-1
- Update to 1.2.3 for blosc 1.3.4

* Wed Jan 08 2014 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.1-8
- Rebuild for blosc

* Tue Nov 05 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-7
- Properly link with blosc shared lib

* Tue Nov 05 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-6
- Disable SSE2 optimizations

* Tue Nov 05 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-5
- Final cosmetic fixes

* Tue Nov 05 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-4
- Fix wrong lib perms

* Fri Oct 18 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-3
- Fixes, thanks to Christopher Meng

* Wed Oct 16 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-2
- Various fixes

* Fri Sep 20 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-1
- Sync to version 1.1

* Mon Jan 2 2012 Thibault North <tnorth@fedoraproject.org> - 1.0.7-1
- Initial package
